@@ -45,7 +45,7 @@
 typedef struct {
   union { // 19.2
     struct {
-      unsigned a : 2; // 8.1
+      unsigned a : 2;
       unsigned : 14;
     };
     uint16_t value;
@@ -894,7 +894,8 @@ void misra_12_3(int a, int b, int c) {
 
   f((1,2),3); // TODO
 
-  for (i=0; i<10; i++, j++){} // 12.3
+  // third clause: 2 persistent side effects instead of 1 (14.2)
+  for (i=0; i<10; i++, j++){} // 12.3 14.2
   for (int i = 0, p = &a1;  // 12.3 14.2
           i < 42;
           ++i, ++p ) // 12.3
@@ -1157,7 +1158,7 @@ static void misra_14_2_init_value(int32_t *var) {
 }
 static void misra_14_2_fn1(bool b) {
   for (;i++<10;) {} // 14.2
-  for (;i<10;dostuff()) {} // TODO
+  for (;i<10;dostuff()) {} // 14.2
   int32_t g = 0;
   int g_arr[42];
   g += 2; // no-warning
@@ -1175,7 +1176,12 @@ static void misra_14_2_fn1(bool b) {
   for (misra_14_2_init_value(&i); i < 10; ++i) {} // no-warning FIXME: False positive for 14.2 Trac #9491
 
   bool abort = false;
-  for (i = 0; (i < 10) && !abort; ++i) { // no-warning
+  for (i = 0; (i < 10) && !abort; ++i) { // 14.2 as 'i' is not a variable
+      if (b) {
+        abort = true;
+      }
+  }
+  for (int i = 0; (i < 10) && !abort; ++i) { // no warning
       if (b) {
         abort = true;
       }
@@ -1186,6 +1192,18 @@ static void misra_14_2_fn1(bool b) {
   for (int i = x; i < 42; i++) {
       x++; // no warning
   }
+  // 1st clause item 2 + loop counter modification
+  for(x = 0; x < 10; x++) {
+    x++; // 14.2
+  }
+  // third clause: 2 persistent side effects instead of 1 (14.2)
+  for (int i = 0; i < 10; i++, x++) { // 12.3 14.2
+  }
+
+  // 2 loop counters, there shall be only 1
+  for(int i=0, j=0; (i<10) && (j<10); i++, j++) { // 12.3 14.2
+  }
+
   for (int i = (x - 3); i < 42; i++) {
       x ^= 3; // no warning
   }
@@ -1218,16 +1236,18 @@ static void misra_14_2_fn2(void)
     for (int i = 0, j = 19; y < 10, --j > 10; y++, j--) { // 14.2 12.3
         i++; // no warning
     }
-    for (int i = 0; y < 10; y++) { // TODO: 14.2
+    // 1st clause is not empty, but is not used in 2nd and 3rd clause
+    for (int i = 0; y < 10; y++) { // 14.2
         i++; // no warning
     }
-    for (int i = 0; i < 10; y++) { // TODO: 14.2
+    for (; y < 10; y++) {} // without 1st clause, no error
+    for (int i = 0; i < 10; y++) { // 14.2
         i++; // no warning
     }
-    for (int i = 0; y < 10; i++) { // TODO: 14.2
+    for (int i = 0; y < 10; i++) { // 14.2
         i++; // no warning
     }
-    for (int i = 0; i < 10; (y+=i)) {
+    for (int i = 0; i < 10; (y+=i)) { // 14.2
         i++; // no warning
     }
 
@@ -1323,7 +1343,7 @@ static void misra_15_4(void) {
       if (y==2) {
         break;
       }
-      for (z = 0; y < 42; ++z) {
+      for (z = 0; y < 42; ++z) { // 14.2
         if (z==1) {
           break;
         }
