@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2018 Cppcheck team.
+ * Copyright (C) 2007-2022 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -98,15 +98,21 @@ protected:
     /**
      * Print help text to the console.
      */
-    static void printHelp();
+    void printHelp();
 
     /**
-     * Print message (to console?).
+     * Print message (to stdout).
      */
     static void printMessage(const std::string &message);
-    static void printMessage(const char* message);
+
+    /**
+     * Print error message (to stdout).
+     */
+    static void printError(const std::string &message);
 
 private:
+    bool isCppcheckPremium() const;
+
     std::vector<std::string> mPathNames;
     std::vector<std::string> mIgnoredPaths;
     Settings *mSettings;
@@ -114,6 +120,7 @@ private:
     bool mShowVersion;
     bool mShowErrorMessages;
     bool mExitAfterPrint;
+    std::string mVSConfig;
 };
 
 /// @}
