@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2021 Cppcheck team.
+ * Copyright (C) 2007-2022 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,11 @@
  */
 
 #include "codeeditstylecontrols.h"
+
 #include <QColorDialog>
 
+class QWidget;
+
 SelectColorButton::SelectColorButton(QWidget* parent) :
     QPushButton(parent),
     mColor(QColor(255, 255, 255))
@@ -57,6 +60,7 @@ void SelectColorButton::setColor(const QColor& color)
     updateColor();
 }
 
+// cppcheck-suppress unusedFunction
 const QColor& SelectColorButton::getColor()
 {
     return mColor;
@@ -114,6 +118,7 @@ void SelectFontWeightCombo::setWeight(const QFont::Weight& weight)
     updateWeight();
 }
 
+// cppcheck-suppress unusedFunction
 const QFont::Weight& SelectFontWeightCombo::getWeight()
 {
     return mWeight;
