@@ -80,7 +80,6 @@
 #define SETTINGS_LANGUAGE               "Application language"
 #define SETTINGS_GLOBAL_INCLUDE_PATHS   "Global include paths"
 #define SETTINGS_PYTHON_PATH            "Python path"
-#define SETTINGS_MISRA_FILE             "MISRA C 2012 file"
 #define SETTINGS_CLANG_PATH             "Clang path"
 #define SETTINGS_VS_INCLUDE_PATHS       "VS include paths"
 #define SETTINGS_INLINE_SUPPRESSIONS    "Inline suppressions"
@@ -90,6 +89,7 @@
 #define SETTINGS_SHOW_STATISTICS        "Show statistics"
 #define SETTINGS_OPEN_PROJECT           "Open Project"
 #define SETTINGS_CHECK_VERSION          "Check Version"
+#define SETTINGS_CHECK_FOR_UPDATES      "Check for updates"
 
 // The maximum value for the progress bar
 #define PROGRESS_MAX                    1024.0
