@@ -35,6 +35,8 @@ class QWidget;
 class QItemSelectionModel;
 class ThreadHandler;
 class QContextMenuEvent;
+class QKeyEvent;
+class QObject;
 class QSettings;
 
 /// @addtogroup GUI
@@ -49,7 +51,7 @@ class ResultsTree : public QTreeView {
     Q_OBJECT
 public:
     explicit ResultsTree(QWidget * parent = nullptr);
-    virtual ~ResultsTree();
+    ~ResultsTree() override;
     void initialize(QSettings *settings, ApplicationList *list, ThreadHandler *checkThreadHandler);
 
     /**
@@ -205,8 +207,6 @@ signals:
     /** Suppress Ids */
     void suppressIds(QStringList ids);
 
-    /** Edit contract for function */
-    void editFunctionContract(QString function);
 public slots:
 
     /**
@@ -284,11 +284,6 @@ protected slots:
      */
     void openContainingFolder();
 
-    /**
-     * @brief Allow user to edit contract to fix bughunting warning
-     */
-    void editContract();
-
     /**
      * @brief Slot for selection change in the results tree.
      *
