@@ -39,9 +39,10 @@ private slots:
     void undefineValid();
     void reflectionValid();
     void markupValid();
+    void containerValid();
 
 private:
-    void loadCfgFile(QString filename, CppcheckLibraryData &data, QString &result, bool removeFile = false);
+    void loadCfgFile(QString filename, CppcheckLibraryData &data, QString &res, bool removeFile = false);
     void saveCfgFile(QString filename, CppcheckLibraryData &data);
 
     CppcheckLibraryData libraryData;
