@@ -120,7 +120,7 @@ std::string AnalyzerInformation::getAnalyzerInfoFile(const std::string &buildDir
 
     const std::string::size_type pos = sourcefile.rfind('/');
     std::string filename;
-    if (pos != std::string::npos)
+    if (pos == std::string::npos)
         filename = sourcefile;
     else
         filename = sourcefile.substr(pos + 1);
