@@ -37,6 +37,7 @@
 #include <map>
 #include <memory>
 #include <set>
+#include <sstream>
 #include <stack>
 #include <string>
 #include <utility>
@@ -163,7 +164,7 @@ static std::vector<std::string> splitString(const std::string &line)
                 line.find("::", pos1) < line.find("<", pos1)) {
                 pos2 = line.find("::", pos1);
                 ret.push_back(line.substr(pos1, pos2-pos1));
-                ret.push_back("::");
+                ret.emplace_back("::");
                 pos1 = pos2 + 2;
                 continue;
             }
@@ -317,8 +318,8 @@ namespace clangimport {
 
     class AstNode {
     public:
-        AstNode(const std::string &nodeType, const std::string &ext, Data *data)
-            : nodeType(nodeType), mExtTokens(splitString(ext)), mData(data)
+        AstNode(std::string nodeType, const std::string &ext, Data *data)
+            : nodeType(std::move(nodeType)), mExtTokens(splitString(ext)), mData(data)
         {}
         std::string nodeType;
         std::vector<AstNodePtr> children;
@@ -497,17 +498,21 @@ void clangimport::AstNode::dumpAst(int num, int indent) const
 void clangimport::AstNode::setLocations(TokenList *tokenList, int file, int line, int col)
 {
     for (const std::string &ext: mExtTokens) {
-        if (ext.compare(0,5,"<col:") == 0)
+        if (ext.compare(0, 5, "<col:") == 0)
             col = std::atoi(ext.substr(5).c_str());
-        else if (ext.compare(0,6,"<line:") == 0) {
+        else if (ext.compare(0, 6, "<line:") == 0) {
             line = std::atoi(ext.substr(6).c_str());
             if (ext.find(", col:") != std::string::npos)
                 col = std::atoi(ext.c_str() + ext.find(", col:") + 6);
-        } else if (ext[0] == '<' && ext.find(":") != std::string::npos) {
-            std::string::size_type sep1 = ext.find(":");
-            std::string::size_type sep2 = ext.find(":", sep1+1);
-            file = tokenList->appendFileIfNew(ext.substr(1, sep1 - 1));
-            line = MathLib::toLongNumber(ext.substr(sep1+1, sep2-sep1));
+        } else if (ext[0] == '<') {
+            const std::string::size_type colon = ext.find(':');
+            if (colon != std::string::npos) {
+                const bool windowsPath = colon == 2 && ext.size() > 4 && ext[3] == '\\';
+                std::string::size_type sep1 = windowsPath ? ext.find(':', 4) : colon;
+                std::string::size_type sep2 = ext.find(':', sep1 + 1);
+                file = tokenList->appendFileIfNew(ext.substr(1, sep1 - 1));
+                line = MathLib::toLongNumber(ext.substr(sep1 + 1, sep2 - sep1 - 1));
+            }
         }
     }
     mFile = file;
@@ -623,7 +628,7 @@ void clangimport::AstNode::setValueType(Token *tok)
         if (!decl.front())
             break;
 
-        ValueType valueType = ValueType::parseDecl(decl.front(), mData->mSettings);
+        ValueType valueType = ValueType::parseDecl(decl.front(), mData->mSettings, true); // TODO: set isCpp
         if (valueType.type != ValueType::Type::UNKNOWN_TYPE) {
             tok->setValueType(new ValueType(valueType));
             break;
@@ -643,7 +648,7 @@ Scope *clangimport::AstNode::createScope(TokenList *tokenList, Scope::ScopeType
 
     Scope *nestedIn = const_cast<Scope *>(getNestedInScope(tokenList));
 
-    symbolDatabase->scopeList.push_back(Scope(nullptr, nullptr, nestedIn));
+    symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nestedIn);
     Scope *scope = &symbolDatabase->scopeList.back();
     if (scopeType == Scope::ScopeType::eEnum)
         scope->enumeratorList.reserve(children2.size());
@@ -968,7 +973,7 @@ Token *clangimport::AstNode::createTokens(TokenList *tokenList)
     if (nodeType == EnumConstantDecl) {
         Token *nameToken = addtoken(tokenList, getSpelling());
         Scope *scope = const_cast<Scope *>(nameToken->scope());
-        scope->enumeratorList.push_back(Enumerator(nameToken->scope()));
+        scope->enumeratorList.emplace_back(nameToken->scope());
         Enumerator *e = &scope->enumeratorList.back();
         e->name = nameToken;
         e->value = mData->enumValue++;
@@ -1004,7 +1009,7 @@ Token *clangimport::AstNode::createTokens(TokenList *tokenList)
             const_cast<Token *>(enumscope->bodyEnd)->deletePrevious();
 
         // Create enum type
-        mData->mSymbolDatabase->typeList.push_back(Type(enumtok, enumscope, enumtok->scope()));
+        mData->mSymbolDatabase->typeList.emplace_back(enumtok, enumscope, enumtok->scope());
         enumscope->definedType = &mData->mSymbolDatabase->typeList.back();
         if (nametok)
             const_cast<Scope *>(enumtok->scope())->definedTypesMap[nametok->str()] = enumscope->definedType;
@@ -1171,7 +1176,7 @@ Token *clangimport::AstNode::createTokens(TokenList *tokenList)
         }
 
         Scope *recordScope = createScope(tokenList, Scope::ScopeType::eStruct, children, classDef);
-        mData->mSymbolDatabase->typeList.push_back(Type(classDef, recordScope, classDef->scope()));
+        mData->mSymbolDatabase->typeList.emplace_back(classDef, recordScope, classDef->scope());
         recordScope->definedType = &mData->mSymbolDatabase->typeList.back();
         if (!recordName.empty()) {
             recordScope->className = recordName;
@@ -1326,7 +1331,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList *tokenList)
         mData->ref(addr, nameToken);
     }
     if (!nameToken->function()) {
-        nestedIn->functionList.push_back(Function(nameToken, unquote(getFullType())));
+        nestedIn->functionList.emplace_back(nameToken, unquote(getFullType()));
         mData->funcDecl(mExtTokens.front(), nameToken, &nestedIn->functionList.back());
         if (nodeType == CXXConstructorDecl)
             nestedIn->functionList.back().type = Function::Type::eConstructor;
@@ -1346,7 +1351,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList *tokenList)
 
     Scope *scope = nullptr;
     if (hasBody) {
-        symbolDatabase->scopeList.push_back(Scope(nullptr, nullptr, nestedIn));
+        symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nestedIn);
         scope = &symbolDatabase->scopeList.back();
         scope->check = symbolDatabase;
         scope->function = function;
@@ -1366,6 +1371,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList *tokenList)
         function->nestedIn = nestedIn;
     function->argDef = par1;
     // Function arguments
+    function->argumentList.reserve(children.size());
     for (int i = 0; i < children.size(); ++i) {
         AstNodePtr child = children[i];
         if (child->nodeType != ParmVarDecl)
@@ -1379,7 +1385,7 @@ void clangimport::AstNode::createTokensFunctionDecl(TokenList *tokenList)
         if (!spelling.empty())
             vartok = child->addtoken(tokenList, spelling);
         if (!prev) {
-            function->argumentList.push_back(Variable(vartok, child->getType(), nullptr, typeEndToken, i, AccessControl::Argument, recordType, scope));
+            function->argumentList.emplace_back(vartok, child->getType(), nullptr, typeEndToken, i, AccessControl::Argument, recordType, scope);
             if (vartok) {
                 const std::string addr = child->mExtTokens[0];
                 mData->varDecl(addr, vartok, &function->argumentList.back());
@@ -1455,7 +1461,7 @@ void clangimport::AstNode::createTokensForCXXRecord(TokenList *tokenList)
         const std::string addr = mExtTokens[0];
         mData->scopeDecl(addr, scope);
         scope->className = className;
-        mData->mSymbolDatabase->typeList.push_back(Type(classToken, scope, classToken->scope()));
+        mData->mSymbolDatabase->typeList.emplace_back(classToken, scope, classToken->scope());
         scope->definedType = &mData->mSymbolDatabase->typeList.back();
         const_cast<Scope *>(classToken->scope())->definedTypesMap[className] = scope->definedType;
     }
@@ -1481,7 +1487,7 @@ Token * clangimport::AstNode::createTokensVarDecl(TokenList *tokenList)
         startToken = startToken->next();
     Token *vartok1 = addtoken(tokenList, name);
     Scope *scope = const_cast<Scope *>(tokenList->back()->scope());
-    scope->varlist.push_back(Variable(vartok1, unquote(type), startToken, vartok1->previous(), 0, scope->defaultAccess(), recordType, scope));
+    scope->varlist.emplace_back(vartok1, unquote(type), startToken, vartok1->previous(), 0, scope->defaultAccess(), recordType, scope);
     mData->varDecl(addr, vartok1, &scope->varlist.back());
     if (mExtTokens.back() == "cinit" && !children.empty()) {
         Token *eq = addtoken(tokenList, "=");
@@ -1519,7 +1525,7 @@ static void setValues(Tokenizer *tokenizer, SymbolDatabase *symbolDatabase)
 {
     const Settings * const settings = tokenizer->getSettings();
 
-    for (Scope &scope: symbolDatabase->scopeList) {
+    for (const Scope& scope : symbolDatabase->scopeList) {
         if (!scope.definedType)
             continue;
 
@@ -1537,7 +1543,7 @@ static void setValues(Tokenizer *tokenizer, SymbolDatabase *symbolDatabase)
 
     for (Token *tok = const_cast<Token*>(tokenizer->tokens()); tok; tok = tok->next()) {
         if (Token::simpleMatch(tok, "sizeof (")) {
-            ValueType vt = ValueType::parseDecl(tok->tokAt(2), settings);
+            ValueType vt = ValueType::parseDecl(tok->tokAt(2), settings, tokenizer->isCPP());
             int sz = vt.typeSize(*settings, true);
             if (sz <= 0)
                 continue;
@@ -1562,7 +1568,7 @@ void clangimport::parseClangAstDump(Tokenizer *tokenizer, std::istream &f)
 
     tokenizer->createSymbolDatabase();
     SymbolDatabase *symbolDatabase = const_cast<SymbolDatabase *>(tokenizer->getSymbolDatabase());
-    symbolDatabase->scopeList.push_back(Scope(nullptr, nullptr, nullptr));
+    symbolDatabase->scopeList.emplace_back(nullptr, nullptr, nullptr);
     symbolDatabase->scopeList.back().type = Scope::ScopeType::eGlobal;
     symbolDatabase->scopeList.back().check = symbolDatabase;
 
