@@ -49,6 +49,7 @@
 #include <memory>
 #include <new>
 #include <set>
+#include <sstream>
 #include <stdexcept>
 #include <string>
 #include <utility>
@@ -88,7 +89,7 @@ namespace {
         std::string args;       // special extra arguments
         std::string python;     // script interpreter
         bool ctu = false;
-        std::string runScript{};
+        std::string runScript;
 
         static std::string getFullPath(const std::string &fileName, const std::string &exename) {
             if (Path::fileExists(fileName))
@@ -232,7 +233,7 @@ static std::string getDumpFileName(const Settings& settings, const std::string&
     if (!settings.dumpFile.empty())
         return settings.dumpFile;
     if (!settings.dump && !settings.buildDir.empty())
-        return AnalyzerInformation::getAnalyzerInfoFile(settings.buildDir, filename, "") + ".dump";
+        return AnalyzerInformation::getAnalyzerInfoFile(settings.buildDir, filename, emptyString) + ".dump";
     return filename + ".dump";
 }
 
@@ -243,8 +244,6 @@ static std::string getCtuInfoFileName(const std::string &dumpFile)
 
 static void createDumpFile(const Settings& settings,
                            const std::string& filename,
-                           const std::vector<std::string>& files,
-                           const simplecpp::Token* rawtokens,
                            std::ofstream& fdump,
                            std::string& dumpFile)
 {
@@ -271,25 +270,12 @@ static void createDumpFile(const Settings& settings,
           << " long_long_bit=\"" << settings.long_long_bit << '\"'
           << " pointer_bit=\"" << (settings.sizeof_pointer * settings.char_bit) << '\"'
           << "/>\n";
-    if (rawtokens) {
-        fdump << "  <rawtokens>" << std::endl;
-        for (unsigned int i = 0; i < files.size(); ++i)
-            fdump << "    <file index=\"" << i << "\" name=\"" << ErrorLogger::toxml(files[i]) << "\"/>" << std::endl;
-        for (const simplecpp::Token *tok = rawtokens; tok; tok = tok->next) {
-            fdump << "    <tok "
-                  << "fileIndex=\"" << tok->location.fileIndex << "\" "
-                  << "linenr=\"" << tok->location.line << "\" "
-                  << "column=\"" << tok->location.col << "\" "
-                  << "str=\"" << ErrorLogger::toxml(tok->str()) << "\""
-                  << "/>" << std::endl;
-        }
-        fdump << "  </rawtokens>" << std::endl;
-    }
 }
 
 static std::string executeAddon(const AddonInfo &addonInfo,
                                 const std::string &defaultPythonExe,
                                 const std::string &file,
+                                const std::string &premiumArgs,
                                 std::function<bool(std::string,std::vector<std::string>,std::string,std::string*)> executeCommand)
 {
     const std::string redirect = "2>&1";
@@ -323,6 +309,8 @@ static std::string executeAddon(const AddonInfo &addonInfo,
     if (addonInfo.executable.empty())
         args = cmdFileName(addonInfo.runScript) + " " + cmdFileName(addonInfo.scriptFile);
     args += std::string(args.empty() ? "" : " ") + "--cli" + addonInfo.args;
+    if (!premiumArgs.empty() && !addonInfo.executable.empty())
+        args += " " + premiumArgs;
 
     const std::string fileArg = (endsWith(file, FILELIST, sizeof(FILELIST)-1) ? " --file-list " : " ") + cmdFileName(file);
     args += fileArg;
@@ -332,7 +320,7 @@ static std::string executeAddon(const AddonInfo &addonInfo,
         std::string message("Failed to execute addon (command: '" + pythonExe + " " + args + "'). Exitcode is nonzero.");
         if (result.size() > 2) {
             message = message + "\n" + message + "\nOutput:\n" + result;
-            message = message.substr(0,message.find_last_not_of("\n\r"));
+            message.resize(message.find_last_not_of("\n\r"));
         }
         throw InternalError(nullptr, message);
     }
@@ -367,7 +355,7 @@ CppCheck::CppCheck(ErrorLogger &errorLogger,
     , mUseGlobalSuppressions(useGlobalSuppressions)
     , mTooManyConfigs(false)
     , mSimplify(true)
-    , mExecuteCommand(executeCommand)
+    , mExecuteCommand(std::move(executeCommand))
 {}
 
 CppCheck::~CppCheck()
@@ -416,14 +404,13 @@ static bool reportClangErrors(std::istream &is, std::function<void(const ErrorMe
         const std::string colnr = line.substr(pos2+1, pos3-pos2-1);
         const std::string msg = line.substr(line.find(":", pos3+1) + 2);
 
-        std::list<ErrorMessage::FileLocation> locationList;
+        const std::string locFile = Path::toNativeSeparators(filename);
         ErrorMessage::FileLocation loc;
-        loc.setfile(Path::toNativeSeparators(filename));
+        loc.setfile(locFile);
         loc.line = std::atoi(linenr.c_str());
         loc.column = std::atoi(colnr.c_str());
-        locationList.push_back(loc);
-        ErrorMessage errmsg(locationList,
-                            loc.getfile(),
+        ErrorMessage errmsg({std::move(loc)},
+                            locFile,
                             Severity::error,
                             msg,
                             "syntaxError",
@@ -448,7 +435,7 @@ unsigned int CppCheck::check(const std::string &path)
             mErrorLogger.reportOut(std::string("Checking ") + path + "...", Color::FgGreen);
 
         const std::string lang = Path::isCPP(path) ? "-x c++" : "-x c";
-        const std::string analyzerInfo = mSettings.buildDir.empty() ? std::string() : AnalyzerInformation::getAnalyzerInfoFile(mSettings.buildDir, path, "");
+        const std::string analyzerInfo = mSettings.buildDir.empty() ? std::string() : AnalyzerInformation::getAnalyzerInfoFile(mSettings.buildDir, path, emptyString);
         const std::string clangcmd = analyzerInfo + ".clang-cmd";
         const std::string clangStderr = analyzerInfo + ".clang-stderr";
         const std::string clangAst = analyzerInfo + ".clang-ast";
@@ -520,7 +507,7 @@ unsigned int CppCheck::check(const std::string &path)
             // create dumpfile
             std::ofstream fdump;
             std::string dumpFile;
-            createDumpFile(mSettings, path, tokenizer.list.getFiles(), nullptr, fdump, dumpFile);
+            createDumpFile(mSettings, path, fdump, dumpFile);
             if (fdump.is_open()) {
                 fdump << "<dump cfg=\"\">" << std::endl;
                 for (const ErrorMessage& errmsg: compilerWarnings)
@@ -686,15 +673,27 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             plistFile << ErrorLogger::plistHeader(version(), files);
         }
 
-        // write dump file xml prolog
-        std::ofstream fdump;
-        std::string dumpFile;
-        createDumpFile(mSettings, filename, files, tokens1.cfront(), fdump, dumpFile);
+        std::ostringstream dumpProlog;
+        if (mSettings.dump || !mSettings.addons.empty()) {
+            dumpProlog << "  <rawtokens>" << std::endl;
+            for (unsigned int i = 0; i < files.size(); ++i)
+                dumpProlog << "    <file index=\"" << i << "\" name=\"" << ErrorLogger::toxml(files[i]) << "\"/>" << std::endl;
+            for (const simplecpp::Token *tok = tokens1.cfront(); tok; tok = tok->next) {
+                dumpProlog
+                    << "    <tok "
+                    << "fileIndex=\"" << tok->location.fileIndex << "\" "
+                    << "linenr=\"" << tok->location.line << "\" "
+                    << "column=\"" << tok->location.col << "\" "
+                    << "str=\"" << ErrorLogger::toxml(tok->str()) << "\""
+                    << "/>" << std::endl;
+            }
+            dumpProlog << "  </rawtokens>" << std::endl;
+        }
 
         // Parse comments and then remove them
         preprocessor.inlineSuppressions(tokens1);
-        if ((mSettings.dump || !mSettings.addons.empty()) && fdump.is_open()) {
-            mSettings.nomsg.dump(fdump);
+        if (mSettings.dump || !mSettings.addons.empty()) {
+            mSettings.nomsg.dump(dumpProlog);
         }
         tokens1.removeComments();
         preprocessor.removeComments();
@@ -711,10 +710,10 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             toolinfo << mSettings.userDefines;
             mSettings.nomsg.dump(toolinfo);
 
-            // Calculate checksum so it can be compared with old checksum / future checksums
-            const unsigned int checksum = preprocessor.calculateChecksum(tokens1, toolinfo.str());
+            // Calculate hash so it can be compared with old hash / future hashes
+            const std::size_t hash = preprocessor.calculateHash(tokens1, toolinfo.str());
             std::list<ErrorMessage> errors;
-            if (!mAnalyzerInformation.analyzeFile(mSettings.buildDir, filename, cfgname, checksum, &errors)) {
+            if (!mAnalyzerInformation.analyzeFile(mSettings.buildDir, filename, cfgname, hash, &errors)) {
                 while (!errors.empty()) {
                     reportErr(errors.front());
                     errors.pop_front();
@@ -723,6 +722,15 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             }
         }
 
+        // write dump file xml prolog
+        std::ofstream fdump;
+        std::string dumpFile;
+        createDumpFile(mSettings, filename, fdump, dumpFile);
+        if (fdump.is_open()) {
+            fdump << dumpProlog.str();
+            dumpProlog.str("");
+        }
+
         // Get directives
         preprocessor.setDirectives(tokens1);
         preprocessor.simplifyPragmaAsm(&tokens1);
@@ -770,7 +778,7 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             }
         }
 
-        std::set<unsigned long long> checksums;
+        std::set<unsigned long long> hashes;
         int checkCount = 0;
         bool hasValidConfig = false;
         std::list<std::string> configurationError;
@@ -866,18 +874,18 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                     fdump << "</dump>" << std::endl;
                 }
 
-                // Need to call this even if the checksum will skip this configuration
+                // Need to call this even if the hash will skip this configuration
                 mSettings.nomsg.markUnmatchedInlineSuppressionsAsChecked(tokenizer);
 
                 // Skip if we already met the same simplified token list
                 if (mSettings.force || mSettings.maxConfigs > 1) {
-                    const unsigned long long checksum = tokenizer.list.calculateChecksum();
-                    if (checksums.find(checksum) != checksums.end()) {
+                    const std::size_t hash = tokenizer.list.calculateHash();
+                    if (hashes.find(hash) != hashes.end()) {
                         if (mSettings.debugwarnings)
                             purgedConfigurationMessage(filename, mCurrentConfig);
                         continue;
                     }
-                    checksums.insert(checksum);
+                    hashes.insert(hash);
                 }
 
                 // Check normal tokens
@@ -887,20 +895,9 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
                 if (!mSettings.buildDir.empty())
                     checkUnusedFunctions.parseTokens(tokenizer, filename.c_str(), &mSettings);
 
-                // simplify more if required, skip rest of iteration if failed
-                if (mSimplify && hasRule("simple")) {
-                    std::cout << "Handling of \"simple\" rules is deprecated and will be removed in Cppcheck 2.5." << std::endl;
-
-                    // if further simplification fails then skip rest of iteration
-                    Timer timer3("Tokenizer::simplifyTokenList2", mSettings.showtime, &s_timerResults);
-                    result = tokenizer.simplifyTokenList2();
-                    timer3.stop();
-                    if (!result)
-                        continue;
-
-                    if (!Settings::terminated())
-                        executeRules("simple", tokenizer);
-                }
+                // handling of "simple" rules has been removed.
+                if (mSimplify && hasRule("simple"))
+                    throw InternalError(nullptr, "Handling of \"simple\" rules has been removed in Cppcheck. Use --addon instead.");
 
             } catch (const simplecpp::Output &o) {
                 // #error etc during preprocessing
@@ -939,12 +936,11 @@ unsigned int CppCheck::checkFile(const std::string& filename, const std::string
             for (const std::string &s : configurationError)
                 msg += '\n' + s;
 
-            std::list<ErrorMessage::FileLocation> locationList;
+            const std::string locFile = Path::toNativeSeparators(filename);
             ErrorMessage::FileLocation loc;
-            loc.setfile(Path::toNativeSeparators(filename));
-            locationList.push_back(loc);
-            ErrorMessage errmsg(locationList,
-                                loc.getfile(),
+            loc.setfile(locFile);
+            ErrorMessage errmsg({std::move(loc)},
+                                locFile,
                                 Severity::information,
                                 msg,
                                 "noValidConfiguration",
@@ -1373,7 +1369,7 @@ void CppCheck::executeAddons(const std::vector<std::string>& files)
             continue;
 
         const std::string results =
-            executeAddon(addonInfo, mSettings.addonPython, fileList.empty() ? files[0] : fileList, mExecuteCommand);
+            executeAddon(addonInfo, mSettings.addonPython, fileList.empty() ? files[0] : fileList, mSettings.premiumArgs, mExecuteCommand);
         std::istringstream istr(results);
         std::string line;
 
@@ -1395,7 +1391,7 @@ void CppCheck::executeAddons(const std::vector<std::string>& files)
                 const std::string fileName = obj["file"].get<std::string>();
                 const int64_t lineNumber = obj["linenr"].get<int64_t>();
                 const int64_t column = obj["column"].get<int64_t>();
-                errmsg.callStack.emplace_back(ErrorMessage::FileLocation(fileName, lineNumber, column));
+                errmsg.callStack.emplace_back(fileName, lineNumber, column);
             } else if (obj.count("loc") > 0) {
                 for (const picojson::value &locvalue: obj["loc"].get<picojson::array>()) {
                     picojson::object loc = locvalue.get<picojson::object>();
@@ -1403,7 +1399,7 @@ void CppCheck::executeAddons(const std::vector<std::string>& files)
                     const int64_t lineNumber = loc["linenr"].get<int64_t>();
                     const int64_t column = loc["column"].get<int64_t>();
                     const std::string info = loc["info"].get<std::string>();
-                    errmsg.callStack.emplace_back(ErrorMessage::FileLocation(fileName, info, lineNumber, column));
+                    errmsg.callStack.emplace_back(fileName, info, lineNumber, column);
                 }
             }
 
@@ -1442,8 +1438,9 @@ void CppCheck::executeAddonsWholeProgram(const std::map<std::string, std::size_t
         mExitCode = 1;
     }
 
-    for (const std::string &f: ctuInfoFiles) {
-        std::remove(f.c_str());
+    if (mSettings.buildDir.empty()) {
+        for (const std::string &f: ctuInfoFiles)
+            std::remove(f.c_str());
     }
 }
 
@@ -1589,10 +1586,10 @@ void CppCheck::getErrorMessages()
     s.severity.enable(Severity::performance);
     s.severity.enable(Severity::information);
 
-    purgedConfigurationMessage("","");
+    purgedConfigurationMessage(emptyString,emptyString);
 
     mTooManyConfigs = true;
-    tooManyConfigsError("",0U);
+    tooManyConfigsError(emptyString,0U);
 
     // call all "getErrorMessages" in all registered Check classes
     for (std::list<Check *>::const_iterator it = Check::instances().begin(); it != Check::instances().end(); ++it)
@@ -1618,7 +1615,7 @@ void CppCheck::analyseClangTidy(const ImportProject::FileSettings &fileSettings)
 
     const std::string args = "-quiet -checks=*,-clang-analyzer-*,-llvm* \"" + fileSettings.filename + "\" -- " + allIncludes + allDefines;
     std::string output;
-    if (!mExecuteCommand(exe, split(args), "", &output)) {
+    if (!mExecuteCommand(exe, split(args), emptyString, &output)) {
         std::cerr << "Failed to execute '" << exe << "'" << std::endl;
         return;
     }
@@ -1628,7 +1625,7 @@ void CppCheck::analyseClangTidy(const ImportProject::FileSettings &fileSettings)
     std::string line;
 
     if (!mSettings.buildDir.empty()) {
-        const std::string analyzerInfoFile = AnalyzerInformation::getAnalyzerInfoFile(mSettings.buildDir, fileSettings.filename, "");
+        const std::string analyzerInfoFile = AnalyzerInformation::getAnalyzerInfoFile(mSettings.buildDir, fileSettings.filename, emptyString);
         std::ofstream fcmd(analyzerInfoFile + ".clang-tidy-cmd");
         fcmd << istr.str();
     }
@@ -1660,7 +1657,7 @@ void CppCheck::analyseClangTidy(const ImportProject::FileSettings &fileSettings)
         fixedpath = Path::toNativeSeparators(fixedpath);
 
         ErrorMessage errmsg;
-        errmsg.callStack.emplace_back(ErrorMessage::FileLocation(fixedpath, lineNumber, column));
+        errmsg.callStack.emplace_back(fixedpath, lineNumber, column);
 
         errmsg.id = "clang-tidy-" + errorString.substr(1, errorString.length() - 2);
         if (errmsg.id.find("performance") != std::string::npos)
