@@ -97,9 +97,9 @@ void Settings::loadCppcheckCfg()
         for (const picojson::value &v : obj["addons"].get<picojson::array>()) {
             const std::string &s = v.get<std::string>();
             if (!Path::isAbsolute(s))
-                addons.push_back(Path::getPathFromFilename(fileName) + s);
+                addons.emplace(Path::getPathFromFilename(fileName) + s);
             else
-                addons.push_back(s);
+                addons.emplace(s);
         }
     }
     if (obj.count("suppressions") && obj["suppressions"].is<picojson::array>()) {
