@@ -83,8 +83,8 @@ namespace ValueFlow {
     };
     class CPPCHECKLIB Value {
     public:
-        typedef std::pair<const Token *, std::string> ErrorPathItem;
-        typedef std::list<ErrorPathItem> ErrorPath;
+        using ErrorPathItem = std::pair<const Token *, std::string>;
+        using ErrorPath = std::list<ErrorPathItem>;
         enum class Bound { Upper, Lower, Point };
 
         explicit Value(long long val = 0, Bound b = Bound::Point)
@@ -93,7 +93,6 @@ namespace ValueFlow {
             intvalue(val),
             tokvalue(nullptr),
             floatValue(0.0),
-            moveKind(MoveKind::NonMovedVariable),
             varvalue(val),
             condition(nullptr),
             varId(0U),
@@ -102,6 +101,7 @@ namespace ValueFlow {
             macro(false),
             defaultArg(false),
             indirect(0),
+            moveKind(MoveKind::NonMovedVariable),
             path(0),
             wideintvalue(val),
             subexpressions(),
@@ -251,6 +251,8 @@ namespace ValueFlow {
 
         std::string infoString() const;
 
+        std::string toString() const;
+
         enum class ValueType {
             INT,
             TOK,
@@ -329,9 +331,6 @@ namespace ValueFlow {
         /** float value */
         double floatValue;
 
-        /** kind of moved  */
-        enum class MoveKind {NonMovedVariable, MovedVariable, ForwardedVariable} moveKind;
-
         /** For calculated values - variable value that calculated value depends on */
         long long varvalue;
 
@@ -340,6 +339,8 @@ namespace ValueFlow {
 
         ErrorPath errorPath;
 
+        ErrorPath debugPath;
+
         /** For calculated values - varId that calculated value depends on */
         nonneg int varId;
 
@@ -357,6 +358,9 @@ namespace ValueFlow {
 
         int indirect;
 
+        /** kind of moved  */
+        enum class MoveKind {NonMovedVariable, MovedVariable, ForwardedVariable} moveKind;
+
         /** Path id */
         MathLib::bigint path;
 
@@ -468,18 +472,18 @@ bool isContainerSizeChanged(const Token* tok, const Settings* settings = nullptr
 
 struct LifetimeToken {
     const Token* token;
-    bool addressOf;
     ValueFlow::Value::ErrorPath errorPath;
+    bool addressOf;
     bool inconclusive;
 
-    LifetimeToken() : token(nullptr), addressOf(false), errorPath(), inconclusive(false) {}
+    LifetimeToken() : token(nullptr), errorPath(), addressOf(false), inconclusive(false) {}
 
     LifetimeToken(const Token* token, ValueFlow::Value::ErrorPath errorPath)
-        : token(token), addressOf(false), errorPath(std::move(errorPath)), inconclusive(false)
+        : token(token), errorPath(std::move(errorPath)), addressOf(false), inconclusive(false)
     {}
 
     LifetimeToken(const Token* token, bool addressOf, ValueFlow::Value::ErrorPath errorPath)
-        : token(token), addressOf(addressOf), errorPath(std::move(errorPath)), inconclusive(false)
+        : token(token), errorPath(std::move(errorPath)), addressOf(addressOf), inconclusive(false)
     {}
 
     static std::vector<LifetimeToken> setAddressOf(std::vector<LifetimeToken> v, bool b) {
@@ -531,4 +535,6 @@ CPPCHECKLIB std::vector<ValueFlow::Value> getLifetimeObjValues(const Token* tok,
 
 const Token* getEndOfExprScope(const Token* tok, const Scope* defaultScope = nullptr, bool smallest = true);
 
+void combineValueProperties(const ValueFlow::Value& value1, const ValueFlow::Value& value2, ValueFlow::Value* result);
+
 #endif // valueflowH
