@@ -3,6 +3,7 @@
 
 import os
 import re
+import tempfile
 from testutils import create_gui_project_file, cppcheck
 
 # Run Cppcheck from project path
@@ -178,3 +179,16 @@ def test_exclude():
     assert stdout == 'cppcheck: error: no C or C++ source files found.\n'
 
 
+def test_build_dir_dump_output():
+    with tempfile.TemporaryDirectory() as tempdir:
+        args = f'--cppcheck-build-dir={tempdir} --addon=misra helloworld'
+
+        cppcheck(args.split())
+        cppcheck(args.split())
+        with open(f'{tempdir}/main.a1.dump', 'rt') as f:
+            dump = f.read()
+            assert '</dump>' in dump, 'invalid dump data: ...' + dump[-100:]
+
+
+
+
