@@ -26,6 +26,7 @@
 
 #include <iosfwd>
 #include <map>
+#include <sstream>
 #include <string>
 #include <utility>
 #include <vector>
@@ -93,6 +94,7 @@ private:
         TEST_CASE(assign21); // #10186
         TEST_CASE(assign22); // #9139
         TEST_CASE(assign23);
+        TEST_CASE(assign24); // #7440
 
         TEST_CASE(isAutoDealloc);
 
@@ -126,6 +128,7 @@ private:
         TEST_CASE(doublefree10); // #8706
         TEST_CASE(doublefree11);
         TEST_CASE(doublefree12); // #10502
+        TEST_CASE(doublefree13); // #11008
 
         // exit
         TEST_CASE(exit1);
@@ -164,6 +167,9 @@ private:
         TEST_CASE(ifelse22); // #10187
         TEST_CASE(ifelse23); // #5473
         TEST_CASE(ifelse24); // #1733
+        TEST_CASE(ifelse25); // #9966
+        TEST_CASE(ifelse26);
+        TEST_CASE(ifelse27);
 
         // switch
         TEST_CASE(switch1);
@@ -204,6 +210,7 @@ private:
         TEST_CASE(configuration2);
         TEST_CASE(configuration3);
         TEST_CASE(configuration4);
+        TEST_CASE(configuration5);
 
         TEST_CASE(ptrptr);
 
@@ -502,6 +509,23 @@ private:
         settings = s;
     }
 
+    void assign24() { // #7440
+        check("void f() {\n"
+              "    char* data = new char[100];\n"
+              "    char** dataPtr = &data;\n"
+              "    delete[] *dataPtr;\n"
+              "}\n", true);
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f() {\n"
+              "    char* data = new char[100];\n"
+              "    char** dataPtr = &data;\n"
+              "    printf(\"test\");\n"
+              "    delete[] *dataPtr;\n"
+              "}\n", true);
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void isAutoDealloc() {
         check("void f() {\n"
               "    char *p = new char[100];"
@@ -711,7 +735,7 @@ private:
               "    delete foo->ptr;\n"
               "    x = *foo->ptr;\n"
               "}", true);
-        ASSERT_EQUALS("[test.cpp:4]: (error) Dereferencing 'ptr' after it is deallocated / released\n", errout.str());
+        TODO_ASSERT_EQUALS("[test.cpp:4]: (error) Dereferencing 'ptr' after it is deallocated / released\n", "", errout.str());
 
         check("void parse() {\n"
               "    struct Buf {\n"
@@ -1376,6 +1400,20 @@ private:
         ASSERT_EQUALS("", errout.str());
     }
 
+    void doublefree13() { // #11008
+        check("struct buf_t { void* ptr; };\n"
+              "void f() {\n"
+              "    struct buf_t buf;\n"
+              "    if ((buf.ptr = malloc(10)) == NULL)\n"
+              "        return;\n"
+              "    free(buf.ptr);\n"
+              "    if ((buf.ptr = malloc(10)) == NULL)\n"
+              "        return;\n"
+              "    free(buf.ptr);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void exit1() {
         check("void f() {\n"
               "    char *p = malloc(10);\n"
@@ -1423,6 +1461,13 @@ private:
               "  p->x = 0;\n"
               "}");
         ASSERT_EQUALS("", errout.str());
+
+        check("void f(s_t s) {\n" // #11061
+              "    s->p = (char*)malloc(10);\n"
+              "    free((void*)s->p);\n"
+              "    s->p = NULL;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void goto1() {
@@ -1827,6 +1872,44 @@ private:
         TODO_ASSERT_EQUALS("[test.cpp:3]: (error) Memory leak: temp\n", "", errout.str());
     }
 
+    void ifelse25() { // #9966
+        check("void f() {\n"
+              "    void *p, *p2;\n"
+              "    if((p2 = p = malloc(10)) == NULL)\n"
+              "        return;\n"
+              "    (void)p;\n"
+              "    free(p2);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void ifelse26() { // don't crash
+        check("union tidi {\n"
+              "    long long ti;\n"
+              "    unsigned int di[2];\n"
+              "};\n"
+              "void f(long long val) {\n"
+              "    if (val == ({ union tidi d = {.di = {0x0, 0x80000000}}; d.ti; })) {}\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void ifelse27() {
+        check("struct key { void* p; };\n"
+              "int f(struct key** handle) {\n"
+              "    struct key* key;\n"
+              "    if (!(key = calloc(1, sizeof(*key))))\n"
+              "        return 0;\n"
+              "    if (!(key->p = malloc(4))) {\n"
+              "        free(key);\n"
+              "        return 0;\n"
+              "    }\n"
+              "    *handle = key;\n"
+              "    return 1;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void switch1() {
         check("void f() {\n"
               "    char *p = 0;\n"
@@ -2314,6 +2397,43 @@ private:
         ASSERT_EQUALS("[test.c:4]: (information) --check-library: Function set_data() should have <use>/<leak-ignore> configuration\n", errout.str());
     }
 
+    void configuration5() {
+        check("void f() {\n"
+              "    int(i);\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f() {\n"
+              "    static_assert(1 == sizeof(char), \"test\");\n"
+              "}\n", /*cpp*/ true);
+        ASSERT_EQUALS("", errout.str());
+
+        check("namespace pal {\n" // #11237
+              "    struct AutoTimer {};\n"
+              "}\n"
+              "int main() {\n"
+              "    pal::AutoTimer();\n"
+              "}\n", /*cpp*/ true);
+        ASSERT_EQUALS("", errout.str());
+
+        check("struct AutoTimer {};\n"
+              "int main() {\n"
+              "    AutoTimer();\n"
+              "}\n", /*cpp*/ true);
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f() {\n" // #8666
+              "    asm(\"assembler code\");\n"
+              "    asm volatile(\"assembler code\");\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f() {\n" // #11239
+              "    asm goto(\"assembler code\");\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
     void ptrptr() {
         check("void f() {\n"
               "    char **p = malloc(10);\n"
