@@ -16,7 +16,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "settings.h"
 #include "testsuite.h"
 #include "token.h"
@@ -29,6 +28,7 @@
 #include <iterator>
 #include <list>
 #include <ostream>
+#include <sstream>
 #include <string>
 
 
@@ -37,7 +37,7 @@ public:
     TestTokenRange() : TestFixture("TestTokenRange") {}
 
 private:
-    void run() OVERRIDE {
+    void run() override {
         TEST_CASE(enumerationToEnd);
         TEST_CASE(untilHelperToEnd);
         TEST_CASE(untilHelperPartWay);
@@ -46,7 +46,7 @@ private:
         TEST_CASE(exampleAlgorithms);
     }
 
-    std::string testTokenRange(ConstTokenRange range, const Token* start, const Token* end) const {
+    static std::string testTokenRange(ConstTokenRange range, const Token* start, const Token* end) {
         auto tokenToString = [](const Token* t) {
             return t ? t->str() : "<null>";
         };
